@@ -3,8 +3,10 @@
 import logging
 import platform
 from pathlib import Path
+from typing import TYPE_CHECKING
 
-from automate_terminal.utils import run_command
+if TYPE_CHECKING:
+    from automate_terminal.command_service import CommandService
 
 logger = logging.getLogger(__name__)
 
@@ -12,13 +14,14 @@ logger = logging.getLogger(__name__)
 class AppleScriptService:
     """Service for executing AppleScript with optional dry-run mode."""
 
-    def __init__(self, dry_run: bool = False):
+    def __init__(self, command_service: "CommandService"):
         """Initialize AppleScript service.
 
         Args:
-            dry_run: If True, log scripts instead of executing them
+            command_service: Service for executing shell commands
         """
-        self.dry_run = dry_run
+        self.command_service = command_service
+        self.dry_run = command_service.dry_run
         self.is_macos = platform.system() == "Darwin"
 
     def execute(self, script: str) -> bool:
@@ -39,24 +42,11 @@ class AppleScriptService:
             logger.info(script)
             return True
 
-        try:
-            result = run_command(
-                ["osascript", "-e", script],
-                timeout=30,
-                description="Execute AppleScript",
-            )
-
-            success = result.returncode == 0
-            if success:
-                logger.debug("AppleScript executed successfully")
-            else:
-                logger.error(f"AppleScript failed: {result.stderr}")
-
-            return success
-
-        except Exception as e:
-            logger.error(f"Failed to run AppleScript: {e}")
-            return False
+        return self.command_service.execute_r(
+            ["osascript", "-e", script],
+            timeout=30,
+            description="Execute AppleScript",
+        )
 
     def execute_with_result(self, script: str) -> str | None:
         """Execute AppleScript and return the output string.
@@ -77,22 +67,11 @@ class AppleScriptService:
             logger.debug("DRY RUN - Executing query AppleScript:")
             logger.debug(script)
 
-        try:
-            result = run_command(
-                ["osascript", "-e", script],
-                timeout=30,
-                description="Execute AppleScript for output",
-            )
-
-            if result.returncode != 0:
-                logger.error(f"AppleScript failed: {result.stderr}")
-                return None
-
-            return result.stdout.strip()
-
-        except Exception as e:
-            logger.error(f"Failed to run AppleScript: {e}")
-            return None
+        return self.command_service.execute_r_with_output(
+            ["osascript", "-e", script],
+            timeout=30,
+            description="Execute AppleScript for output",
+        )
 
     def escape_string(self, text: str) -> str:
         """Escape text for use in AppleScript strings.
